/* ========================================
 *
 * Copyright YOUR COMPANY, THE YEAR
 * All Rights Reserved
 * UNPUBLISHED, LICENSED SOFTWARE.
 *
 * CONFIDENTIAL AND PROPRIETARY INFORMATION
 * WHICH IS THE PROPERTY OF your company.
 *
 * ========================================
*/
#include "project.h"
//#include <device.h>
#include "stdio.h"
#include "math.h"

// Project Defines
#define FALSE  (0)
#define TRUE   (!FALSE)

// Defines for DMA_In
#define DMA_In_BYTES_PER_BURST 1
#define DMA_In_REQUEST_PER_BURST 1
#define DMA_In_SRC_BASE (CYDEV_PERIPH_BASE)
#define DMA_In_DST_BASE (CYDEV_PERIPH_BASE)

// Defines for DMA_Out
//#define DMA_Out_BYTES_PER_BURST 2 // should be 1 (one), VDAC is 8 bits wide
#define DMA_Out_BYTES_PER_BURST 1
#define DMA_Out_REQUEST_PER_BURST 1
#define DMA_Out_SRC_BASE (CYDEV_PERIPH_BASE)
#define DMA_Out_DST_BASE (CYDEV_PERIPH_BASE)

// Variables to store ADC result
int32 Output[2];
int32 Offset;
//Variable used to select ADC channel
volatile char Channel[2];
// Flags used to store transmit data commands
volatile char ContinuouslySendData;
// Transmit Buffer
char TransmitBuffer[160];
    // Variable declarations for DMA_In
    // Move these variable declarations to the top of the function
    uint8 DMA_In_Chan;
    uint8 DMA_In_TD[1];
    
    // Variable declarations for DMA_Out
    // Move these variable declarations to the top of the function
    uint8 DMA_Out_Chan;
    uint8 DMA_Out_TD[1];
    

CY_ISR(InterRX)
{
// Variable to store UART received character
char Ch;
    // Non-blocking call to get the latest data recieved
    Ch = UART_GetChar();
    switch(Ch)
    {
        // Set flags based on UART command
        case 'S':
        case 's':
            ContinuouslySendData = TRUE;
        break;
        case 'X':
        case 'x':
            ContinuouslySendData = FALSE;
        break;
        case '1':
            Channel[0] = TRUE;
            Channel[1] = FALSE;
        break;
        case '2':
            Channel[0] = FALSE;
            Channel[1] = TRUE;
        break;
        default:
            // Place error handling code here
        break;    
        }
}

void Initialize_System()
{
    CyGlobalIntEnable;  	// Enable global interrupts
	
    //Initializes all devices
    Filter_SetCoherency(Filter_CHANNEL_A, Filter_KEY_LOW);
    Filter_Start();    
    VDAC_Start();
    UART_Start();
    
    //Initializes interruptions
    isrReceive_StartEx(InterRX);
    
    /* DMA Configuration for DMA_In */
    DMA_In_Chan = DMA_In_DmaInitialize(DMA_In_BYTES_PER_BURST, DMA_In_REQUEST_PER_BURST, 
        HI16(DMA_In_SRC_BASE), HI16(DMA_In_DST_BASE));
    DMA_In_TD[0] = CyDmaTdAllocate();
    CyDmaTdSetConfiguration(DMA_In_TD[0], 2, DMA_In_TD[0], 0);
    CyDmaTdSetAddress(DMA_In_TD[0], LO16((uint32)ADC_SAR_WRK0_PTR), LO16((uint32)Filter_STAGEA_PTR));
    CyDmaChSetInitialTd(DMA_In_Chan, DMA_In_TD[0]);
    CyDmaChEnable(DMA_In_Chan, 1);

    /* DMA Configuration for DMA_Out */
    DMA_Out_Chan = DMA_Out_DmaInitialize(DMA_Out_BYTES_PER_BURST, DMA_Out_REQUEST_PER_BURST, 
        HI16(DMA_Out_SRC_BASE), HI16(DMA_Out_DST_BASE));
    DMA_Out_TD[0] = CyDmaTdAllocate();
    CyDmaTdSetConfiguration(DMA_Out_TD[0], 1, DMA_Out_TD[0], 0);
    CyDmaTdSetAddress(DMA_Out_TD[0], LO16((uint32)Filter_HOLDA_PTR), LO16((uint32)VDAC_Data_PTR));
    CyDmaChSetInitialTd(DMA_Out_Chan, DMA_Out_TD[0]);
    CyDmaChEnable(DMA_Out_Chan, 1); 
    ADC_Start();
    ADC_StartConvert();    
}

int main(void)
{
	Initialize_System();
   	UART_PutString("UART is working fine...");    

        
    for(;;)
    {
    }
}

/* [] END OF FILE */
